@@ -2,9 +2,9 @@ package Music::Duration;
 BEGIN {
   $Music::Duration::AUTHORITY = 'cpan:GENE';
 }
-# ABSTRACT: Musical Timing Metrics
+# ABSTRACT: Thirtysecond and sixtyfourth notes
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use strict;
 use warnings;
 
@@ -12,14 +12,11 @@ use MIDI::Simple;
 
 
 {
-    # Calculate named note durations. 
-    my @durations = qw(w h q e s y x);
-
     # Set the initial duration.
-    my $last = 'w';
+    my $last = 's'; # sixteenth
 
-    # Compute the durations for each note.
-    for my $duration (@durations) {
+    # Add 32nd and 64th
+    for my $duration (qw( y x )) {
         # Create a MIDI::Simple format note identifier.
         my $n = $duration . 'n';
 
@@ -48,11 +45,11 @@ __END__
 
 =head1 NAME
 
-Music::Duration - Musical Timing Metrics
+Music::Duration - Thirtysecond and sixtyfourth notes
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -62,13 +59,12 @@ version 0.01
 
 =head1 DESCRIPTION
 
-This module adds C<thirtysecond> (y) and C<sixtyfourth> (x) note divisions to
-L<MIDI>, and corrects the
-L<'dden' duration bug|https://rt.cpan.org/Public/Bug/Display.html?id=60658>.
+This module adds thirtysecond and sixtyfourth note divisions to L<MIDI::Simple>.
+These are 32nd: y, dy, ddy, ty and 64th: x, dx, ddx, tx.
 
 =head1 NAME
 
-Music::Duration - Musical Timing Metrics
+Music::Duration - Thirtysecond and sixtyfourth notes
 
 =head1 TO DO
 
@@ -86,23 +82,11 @@ The code in the C<t/> directory
 
 =head1 AUTHOR
 
-Gene Boggs E<lt>gene@cpan.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2012, Gene Boggs
-
-=head1 LICENSE
-
-This program is free software; you can redistribute or modify it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Gene Boggs.
+This software is copyright (c) 2013 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
